@@ -23,7 +23,7 @@ HEREUNDER IS PROVIDED "AS IS". REGENTS HAS NO OBLIGATION TO PROVIDE
 MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 
 
-The OSC webpage is http://cnmat.cnmat.berkeley.edu/OpenSoundControl
+The OSC webpage is http://opensoundcontrol.org
 */
 
 /* OSC-route.c
@@ -31,16 +31,16 @@ The OSC webpage is http://cnmat.cnmat.berkeley.edu/OpenSoundControl
 
   To-do:
 
-  	Match a pattern against a pattern?
+  Match a pattern against a pattern?
       [Done: Only Slash-Star is allowed, see MyPatternMatch.]
-  	Declare outlet types / distinguish leaf nodes from other children
-  	More sophisticated (2-pass?) allmessages scheme
-  	set message?
+  Declare outlet types / distinguish leaf nodes from other children
+  More sophisticated (2-pass?) allmessages scheme
+  set message?
 
 
-	pd
-	-------------
-		-- tweaks for Win32    www.zeggz.com/raf	13-April-2002
+pd
+-------------
+-- tweaks for Win32    www.zeggz.com/raf 13-April-2002
 
 */
 /* OSC-pattern-match.c header follows: */
@@ -69,7 +69,7 @@ HEREUNDER IS PROVIDED "AS IS". REGENTS HAS NO OBLIGATION TO PROVIDE
 MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 
 The OpenSound Control WWW page is
-    http://www.cnmat.berkeley.edu/OpenSoundControl
+    http://opensoundcontrol.org
 */
 
 
@@ -90,7 +90,7 @@ typedef struct _routeOSC
     t_object    x_obj; /* required header */
     int         x_num; /* Number of prefixes we store */
     int         x_verbosity; /* level of debug output required */
-    char        **x_prefixes; /* the OSC addresses to be matched */
+    const char  **x_prefixes; /* the OSC addresses to be matched */
     int         *x_prefix_depth; /* the number of slashes in each prefix */
     void        **x_outlets; /* one for each prefix plus one for everything else */
 } t_routeOSC;
@@ -99,7 +99,7 @@ typedef struct _routeOSC
 
 void routeOSC_setup(void);
 static void routeOSC_free(t_routeOSC *x);
-static int MyPatternMatch (const char *pattern, const char *test);
+static int MyPatternMatch (void *x, const char *pattern, const char *test);
 static void routeOSC_doanything(t_routeOSC *x, t_symbol *s, int argc, t_atom *argv);
 static void routeOSC_bang(t_routeOSC *x);
 static void routeOSC_float(t_routeOSC *x, t_floatarg f);
@@ -107,33 +107,33 @@ static void routeOSC_symbol(t_routeOSC *x, t_symbol *s);
 static void routeOSC_list(t_routeOSC *x, t_symbol *s, int argc, t_atom *argv);
 static void *routeOSC_new(t_symbol *s, int argc, t_atom *argv);
 static void routeOSC_set(t_routeOSC *x, t_symbol *s, int argc, t_atom *argv);
-static void routeOSC_paths(t_routeOSC *x, t_symbol *s, int argc, t_atom *argv);
+static void routeOSC_paths(t_routeOSC *x);
 static void routeOSC_verbosity(t_routeOSC *x, t_floatarg v);
-static int routeOSC_count_slashes(char *prefix);
-static char *NextSlashOrNull(char *p);
-static char *NthSlashOrNull(char *p, int n);
+static int routeOSC_count_slashes(const char *prefix);
+static const char *NextSlashOrNull(const char *p);
+static const char *NthSlashOrNull(const char *p, int n);
 static void StrCopyUntilSlash(char *target, const char *source);
 static void StrCopyUntilNthSlash(char *target, const char *source, int n);
 
 /* from
     OSC-pattern-match.c
 */
-static const char *theWholePattern;	/* Just for warning messages */
-static int MatchBrackets (const char *pattern, const char *test);
-static int MatchList (const char *pattern, const char *test);
-static int PatternMatch (const char *  pattern, const char * test);
+static const char *theWholePattern; /* Just for warning messages */
+static int MatchBrackets (void *x, const char *pattern, const char *test);
+static int MatchList (void *x, const char *pattern, const char *test);
+static int PatternMatch (void *x, const char *pattern, const char *test);
 
 static t_class *routeOSC_class;
 t_symbol *ps_list, *ps_complain, *ps_emptySymbol;
 
-static int MyPatternMatch (const char *pattern, const char *test)
+static int MyPatternMatch (void *x, const char *pattern, const char *test)
 {
     // This allows the special case of "routeOSC /* " to be an outlet that
     // matches anything; i.e., it always outputs the input with the first level
     // of the address stripped off.
 
     if (test[0] == '*' && test[1] == '\0') return 1;
-    else return PatternMatch(pattern, test);
+    else return PatternMatch(x, pattern, test);
 }
 
 static void routeOSC_free(t_routeOSC *x)
@@ -155,7 +155,7 @@ void routeOSC_setup(void)
     class_addsymbol(routeOSC_class, routeOSC_symbol);
     class_addlist(routeOSC_class, routeOSC_list);
     class_addmethod(routeOSC_class, (t_method)routeOSC_set, gensym("set"), A_GIMME, 0);
-    class_addmethod(routeOSC_class, (t_method)routeOSC_paths, gensym("paths"), A_GIMME, 0);
+    class_addmethod(routeOSC_class, (t_method)routeOSC_paths, gensym("paths"), 0);
     class_addmethod(routeOSC_class, (t_method)routeOSC_verbosity, gensym("verbosity"), A_DEFFLOAT, 0);
 
     ps_emptySymbol = gensym("");
@@ -173,7 +173,7 @@ static void *routeOSC_new(t_symbol *s, int argc, t_atom *argv)
 
     if (argc > MAX_NUM)
     {
-        error("* routeOSC: too many arguments: %d (max %d)", argc, MAX_NUM);
+        pd_error(x, "* %s: too many arguments: %d (max %d)", s->s_name, argc, MAX_NUM);
         return 0;
     }
     x->x_num = 0;
@@ -188,18 +188,18 @@ static void *routeOSC_new(t_symbol *s, int argc, t_atom *argv)
             }
             else
             {
-                error("routeOSC: argument %d does not begin with a slash(/).", i);
+                pd_error(x, "%s: argument %d does not begin with a slash(/).", s->s_name, i);
                 return(0);
             }
         }
         else
         {
-            error("routeOSC: argument %d is not a symbol.", i);
+            pd_error(x, "%s: argument %d is not a symbol.", s->s_name, i);
             return 0;
         }
     }
 /* now allocate the storage for each path */
-    x->x_prefixes = (char **)getzbytes(x->x_num*sizeof(char *)); /* the OSC addresses to be matched */
+    x->x_prefixes = (const char **)getzbytes(x->x_num*sizeof(const char *)); /* the OSC addresses to be matched */
     x->x_prefix_depth = (int *)getzbytes(x->x_num*sizeof(int));  /* the number of slashes in each prefix */
     x->x_outlets = (void **)getzbytes((x->x_num+1)*sizeof(void *)); /* one for each prefix plus one for everything else */
 /* put the pointer to the path in x_prefixes */
@@ -222,6 +222,7 @@ static void *routeOSC_new(t_symbol *s, int argc, t_atom *argv)
 static void routeOSC_set(t_routeOSC *x, t_symbol *s, int argc, t_atom *argv)
 {
     int i;
+    (void)s;
 
     if (argc > x->x_num)
     {
@@ -251,10 +252,10 @@ static void routeOSC_set(t_routeOSC *x, t_symbol *s, int argc, t_atom *argv)
     }
 }
 
-static void routeOSC_paths(t_routeOSC *x, t_symbol *s, int argc, t_atom *argv)
+static void routeOSC_paths(t_routeOSC *x)
 { /* print  out the paths we are matching */
     int i;
-    
+
     for (i = 0; i < x->x_num; ++i) post("path[%d]: %s (depth %d)", i, x->x_prefixes[i], x->x_prefix_depth[i]);
 }
 
@@ -264,10 +265,10 @@ static void routeOSC_verbosity(t_routeOSC *x, t_floatarg v)
     if (x->x_verbosity) post("routeOSC_verbosity(%p) is %d", x, x->x_verbosity);
 }
 
-static int routeOSC_count_slashes(char *prefix)
+static int routeOSC_count_slashes(const char *prefix)
 { /* find the path depth of the prefix by counting the numberof slashes */
     int i = 0;
-    char *p = prefix;
+    const char *p = prefix;
 
     while (*p != '\0') if (*p++ == '/') i++;
     return i;
@@ -275,7 +276,7 @@ static int routeOSC_count_slashes(char *prefix)
 
 static void routeOSC_doanything(t_routeOSC *x, t_symbol *s, int argc, t_atom *argv)
 {
-    char    *pattern, *nextSlash;
+    const char    *pattern, *nextSlash;
     int     i = 0, pattern_depth = 0, matchedAnything = 0;
     int     noPath = 0; // nonzero if we are dealing with a simple list (as from a previous [routeOSC])
 
@@ -294,13 +295,13 @@ static void routeOSC_doanything(t_routeOSC *x, t_symbol *s, int argc, t_atom *ar
     if (*nextSlash == '\0')
     { /* pattern_depth == 1 */
         /* last level of the address, so we'll output the argument list */
-    
+
         for (i = 0; i < x->x_num; ++i)
         {
             if
             (
                 (x->x_prefix_depth[i] <= pattern_depth)
-                && (MyPatternMatch(pattern+1, x->x_prefixes[i]+1))
+                && (MyPatternMatch(x, pattern+1, x->x_prefixes[i]+1))
             )
             {
                 ++matchedAnything;
@@ -367,7 +368,7 @@ static void routeOSC_doanything(t_routeOSC *x, t_symbol *s, int argc, t_atom *ar
                 StrCopyUntilNthSlash(patternBegin, pattern+1, x->x_prefix_depth[i]);
                 if (x->x_verbosity)
                     post("routeOSC_doanything _6_(%p): (%d) patternBegin is %s", x, i, patternBegin);
-                if (MyPatternMatch(patternBegin, x->x_prefixes[i]+1))
+                if (MyPatternMatch(x, patternBegin, x->x_prefixes[i]+1))
                 {
                     if (x->x_verbosity)
                         post("routeOSC_doanything _7_(%p): (%d) matched %s depth %d", x, i, x->x_prefixes[i], x->x_prefix_depth[i]);
@@ -433,7 +434,7 @@ static void routeOSC_list(t_routeOSC *x, t_symbol *s, int argc, t_atom *argv)
     /* output non-OSC data on rightmost outlet */
     if (x->x_verbosity) post("routeOSC_list (%p) s=%s argc is %d", x, s->s_name, argc);
 
-    if (0 == argc) post("routeOSC_list (%p) empty list", x);/* this should never happen but catch it just in case... */
+    if (0 == argc) pd_error(x, "routeOSC_list (%p) empty list", x);/* this should never happen but catch it just in case... */
 
     else if (argv[0].a_type == A_SYMBOL) routeOSC_doanything(x, argv[0].a_w.w_symbol, argc-1, &argv[1]);
 
@@ -444,19 +445,19 @@ static void routeOSC_list(t_routeOSC *x, t_symbol *s, int argc, t_atom *argv)
     }
 }
 
-static char *NextSlashOrNull(char *p)
+static const char *NextSlashOrNull(const char *p)
 {
     while (*p != '/' && *p != '\0') p++;
     return p;
 }
 
-static char *NthSlashOrNull(char *p, int n)
+static const char *NthSlashOrNull(const char *p, int n)
 {
     int i;
     for (i = 0; i < n; ++i)
     {
         while (*p != '/')
-        { 
+        {
             if (*p == '\0') return p;
             p++;
         }
@@ -508,15 +509,15 @@ static void StrCopyUntilNthSlash(char *target, const char *source, int n)
     Adapted from oscpattern.c, by Matt Wright and Amar Chaudhury
 */
 
-static int PatternMatch (const char *  pattern, const char * test)
+static int PatternMatch (void *x, const char *pattern, const char *test)
 {
     theWholePattern = pattern;
-  
+
     if (pattern == 0 || pattern[0] == 0) return test[0] == 0;
-  
+
     if (test[0] == 0)
     {
-        if (pattern[0] == '*') return PatternMatch (pattern+1, test);
+        if (pattern[0] == '*') return PatternMatch (x, pattern+1, test);
         return 0;
     }
 
@@ -525,39 +526,39 @@ static int PatternMatch (const char *  pattern, const char * test)
         case 0:
             return test[0] == 0;
         case '?':
-            return PatternMatch (pattern+1, test+1);
-        case '*': 
-            if (PatternMatch (pattern+1, test)) return 1;
-            return PatternMatch (pattern, test+1);
+            return PatternMatch (x, pattern+1, test+1);
+        case '*':
+            if (PatternMatch (x, pattern+1, test)) return 1;
+            return PatternMatch (x, pattern, test+1);
         case ']':
         case '}':
-                  error("routeOSC: Spurious %c in pattern \".../%s/...\"",pattern[0], theWholePattern);
+                  pd_error(x, "routeOSC: Spurious %c in pattern \".../%s/...\"",pattern[0], theWholePattern);
             return 0;
         case '[':
-            return MatchBrackets (pattern,test);
+            return MatchBrackets (x, pattern,test);
         case '{':
-            return MatchList (pattern,test);
-        case '\\':  
+            return MatchList (x, pattern,test);
+        case '\\':
             if (pattern[1] == 0) return test[0] == 0;
-            if (pattern[1] == test[0]) return PatternMatch (pattern+2,test+1);
+            if (pattern[1] == test[0]) return PatternMatch (x, pattern+2,test+1);
             return 0;
         default:
-            if (pattern[0] == test[0]) return PatternMatch (pattern+1,test+1);
+            if (pattern[0] == test[0]) return PatternMatch (x, pattern+1,test+1);
             return 0;
     }
 }
 
 /* we know that pattern[0] == '[' and test[0] != 0 */
 
-static int MatchBrackets (const char *pattern, const char *test) 
+static int MatchBrackets (void *x, const char *pattern, const char *test)
 {
     int result;
     int negated = 0;
     const char *p = pattern;
 
-    if (pattern[1] == 0) 
+    if (pattern[1] == 0)
     {
-        error("routeOSC: Unterminated [ in pattern \".../%s/...\"", theWholePattern);
+        pd_error(x, "routeOSC: Unterminated [ in pattern \".../%s/...\"", theWholePattern);
         return 0;
     }
     if (pattern[1] == '!')
@@ -567,20 +568,20 @@ static int MatchBrackets (const char *pattern, const char *test)
     }
     while (*p != ']')
     {
-        if (*p == 0) 
+        if (*p == 0)
         {
-            error("Unterminated [ in pattern \".../%s/...\"", theWholePattern);
+            pd_error(x, "Unterminated [ in pattern \".../%s/...\"", theWholePattern);
             return 0;
         }
-        if (p[1] == '-' && p[2] != 0) 
+        if (p[1] == '-' && p[2] != 0)
         {
-            if (test[0] >= p[0] && test[0] <= p[2]) 
+            if (test[0] >= p[0] && test[0] <= p[2])
             {
                 result = !negated;
                 goto advance;
             }
         }
-        if (p[0] == test[0]) 
+        if (p[0] == test[0])
         {
             result = !negated;
             goto advance;
@@ -590,27 +591,27 @@ static int MatchBrackets (const char *pattern, const char *test)
     result = negated;
 advance:
     if (!result) return 0;
-    while (*p != ']') 
+    while (*p != ']')
     {
-        if (*p == 0) 
+        if (*p == 0)
         {
-            error("Unterminated [ in pattern \".../%s/...\"", theWholePattern);
+            pd_error(x, "Unterminated [ in pattern \".../%s/...\"", theWholePattern);
             return 0;
         }
         p++;
     }
-    return PatternMatch (p+1,test+1);
+    return PatternMatch (x, p+1,test+1);
 }
 
-static int MatchList (const char *pattern, const char *test) 
+static int MatchList (void *x, const char *pattern, const char *test)
 {
     const char *restOfPattern, *tp = test;
 
-    for(restOfPattern = pattern; *restOfPattern != '}'; restOfPattern++) 
+    for(restOfPattern = pattern; *restOfPattern != '}'; restOfPattern++)
     {
-        if (*restOfPattern == 0) 
+        if (*restOfPattern == 0)
         {
-            error("Unterminated { in pattern \".../%s/...\"", theWholePattern);
+            pd_error(x, "Unterminated { in pattern \".../%s/...\"", theWholePattern);
             return 0;
         }
     }
@@ -618,19 +619,19 @@ static int MatchList (const char *pattern, const char *test)
     pattern++; /* skip open curly brace */
     while (1)
     {
-        if (*pattern == ',') 
+        if (*pattern == ',')
         {
-            if (PatternMatch (restOfPattern, tp)) return 1;
+            if (PatternMatch (x, restOfPattern, tp)) return 1;
             tp = test;
             ++pattern;
         }
-        else if (*pattern == '}') return PatternMatch (restOfPattern, tp);
-        else if (*pattern == *tp) 
+        else if (*pattern == '}') return PatternMatch (x, restOfPattern, tp);
+        else if (*pattern == *tp)
         {
             ++pattern;
             ++tp;
         }
-        else 
+        else
         {
             tp = test;
             while (*pattern != ',' && *pattern != '}') pattern++;
